<p class="contribute">
  {% assign source_path = page.path %}
  {% assign source_url = source_path | prepend: "https://github.com/groonga/Groonga-HTTP/blob/master/docs/" %}
  <a href="{{ source_url }}">If you find any typo, please feel free to send pull requests!</a>
</p>
